@@ -520,7 +520,9 @@ class CccClient(AbstractClient):
 
 
     def DescribeChatMessages(self, request):
-        """包括具体聊天内容
+        """获取指定服务记录文本聊天内容，需要先使用查询在线客服记录（DescribeIMCdrs） API 获取服务记录 SessionId。
+
+        文本聊天记录只保存了 1 年内的，1 年之前会自动清理。
 
         :param request: Request instance for DescribeChatMessages.
         :type request: :class:`tencentcloud.ccc.v20200210.models.DescribeChatMessagesRequest`
@@ -607,7 +609,7 @@ class CccClient(AbstractClient):
 
 
     def DescribeIMCdrs(self, request):
-        """包括全媒体和文本两种类型
+        """获取包括全媒体和文本会话两种类型的服务记录。
 
         :param request: Request instance for DescribeIMCdrs.
         :type request: :class:`tencentcloud.ccc.v20200210.models.DescribeIMCdrsRequest`
@@ -896,6 +898,35 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def HangUpCall(self, request):
+        """挂断电话
+
+        :param request: Request instance for HangUpCall.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.HangUpCallRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.HangUpCallResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("HangUpCall", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.HangUpCallResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ModifyExtension(self, request):
         """修改话机账号(绑定技能组、绑定坐席账号)
 
